@@ -1,10 +1,7 @@
 #ifndef EXLINEEDIT_H
 #define EXLINEEDIT_H
 
-#include <QtGui>
-#if QT_VERSION >= 0x050000
 #include <QtWidgets>
-#endif
 
 class ClearButton : public QAbstractButton {
 
@@ -50,7 +47,7 @@ protected:
     void paintEvent(QPaintEvent *e);
     void resizeEvent(QResizeEvent *e);
     bool event(QEvent *e);
-    void initStyleOption(QStyleOptionFrameV2 *option) const;
+    void initStyleOption(QStyleOptionFrame *option) const;
 
     QWidget *m_leftWidget;
     QLineEdit *m_lineEdit;
