@@ -21,10 +21,7 @@ $END_LICENSE */
 #ifndef GRIDWIDGET_H
 #define GRIDWIDGET_H
 
-#include <QtGui>
-#if QT_VERSION >= 0x050000
 #include <QtWidgets>
-#endif
 
 class GridWidget : public QWidget {
 
