@@ -21,10 +21,8 @@ $END_LICENSE */
 #ifndef LOADINGWIDGET_H
 #define LOADINGWIDGET_H
 
-#include <QtGui>
-#if QT_VERSION >= 0x050000
 #include <QtWidgets>
-#endif
+
 #include "video.h"
 
 class LoadingWidget : public QWidget {
@@ -37,10 +35,15 @@ public:
     void setError(const QString &message);
     void clear();
 
+protected:
+    void resizeEvent(QResizeEvent *e);
+
 public slots:
     void bufferStatus(int);
 
 private:
+    void adjustFontSize();
+
     QLabel *titleLabel;
     QLabel *descriptionLabel;
     QProgressBar *progressBar;
