@@ -21,17 +21,14 @@ $END_LICENSE */
 #ifndef PAINTERUTILS_H
 #define PAINTERUTILS_H
 
-#include <QtGui>
-#if QT_VERSION >= 0x050000
 #include <QtWidgets>
-#endif
 
 class PainterUtils {
 
 public:
     static void centeredMessage(const QString &message, QWidget* widget);
-    static void topShadow(QWidget *widget);
-    static void paintBadge(QPainter *painter, const QString &text, bool center = false);
+    static void paintBadge(QPainter *painter, const QString &text,
+                           bool center = false, QColor backgroundColor = QColor(230,36,41));
 
 private:
     PainterUtils();
