@@ -21,10 +21,7 @@ $END_LICENSE */
 #ifndef REFINESEARCHBUTTON_H
 #define REFINESEARCHBUTTON_H
 
-#include <QtGui>
-#if QT_VERSION >= 0x050000
 #include <QtWidgets>
-#endif
 
 class RefineSearchButton : public QPushButton
 {
