@@ -1,10 +1,7 @@
 #ifndef SEARCHWIDGET
 #define SEARCHWIDGET
 
-#include <QtGui>
-#if QT_VERSION >= 0x050000
 #include <QtWidgets>
-#endif
 
 class SearchButton;
 class Suggester;
