@@ -1,10 +1,7 @@
 #ifndef SEEKSLIDER_H
 #define SEEKSLIDER_H
 
-#include <QtGui>
-#if QT_VERSION >= 0x050000
 #include <QtWidgets>
-#endif
 
 class SeekSlider : public QSlider {
 
