@@ -21,10 +21,7 @@ $END_LICENSE */
 #ifndef SNAPSHOTPREVIEW_H
 #define SNAPSHOTPREVIEW_H
 
-#include <QtGui>
-#if QT_VERSION >= 0x050000
 #include <QtWidgets>
-#endif
 
 #ifdef APP_PHONON
 #include <phonon/audiooutput.h>
