@@ -21,10 +21,8 @@ $END_LICENSE */
 #ifndef VIDEOSOURCEWIDGET_H
 #define VIDEOSOURCEWIDGET_H
 
-#include <QtGui>
-#if QT_VERSION >= 0x050000
 #include <QtWidgets>
-#endif
+
 #include "gridwidget.h"
 
 class Video;
@@ -36,16 +34,18 @@ class VideoSourceWidget : public GridWidget {
 
 public:
     VideoSourceWidget(VideoSource *videoSource, QWidget *parent = 0);
+    VideoSource *getVideoSource() { return videoSource; }
 
 signals:
     void activated(VideoSource *videoSource);
+    void unavailable(VideoSourceWidget *videoSourceWidget);
 
 protected:
     void paintEvent(QPaintEvent *event);
 
 private slots:
     void activate();
-    void previewVideo(const QList<Video*> &videos);
+    void previewVideo(const QVector<Video*> &videos);
     void setPixmapData(const QByteArray &bytes);
 
 private:
