@@ -2,7 +2,8 @@
 #define YT3_H
 
 #include <QtCore>
-#include <QtNetwork>
+
+class HttpReply;
 
 class YT3 : public QObject {
 
@@ -12,15 +13,13 @@ public:
     static YT3 &instance();
     static const QString &baseUrl();
 
+    void initApiKeys();
     void testApiKey();
     void addApiKey(QUrl &url);
     QUrl method(const QString &name);
 
-signals:
-    void gotChannelId(QString channelId);
-
 private slots:
-    void testResponse(QNetworkReply *reply);
+    void testResponse(const HttpReply &reply);
 
 private:
     YT3();
