@@ -21,10 +21,7 @@ $END_LICENSE */
 #ifndef YTREGIONS_H
 #define YTREGIONS_H
 
-#include <QtGui>
-#if QT_VERSION >= 0x050000
 #include <QtWidgets>
-#endif
 
 struct YTRegion {
     QString id;
@@ -39,17 +36,17 @@ class YTRegions : public QObject {
     Q_OBJECT
 
 public:
-    static const QList<YTRegion> & list();
+    static const QVector<YTRegion> & list();
     static const YTRegion & localRegion();
     static const YTRegion & worldwideRegion();
     static void setRegion(const QString &regionId);
     static QString currentRegionId();
-    static YTRegion currentRegion();
+    static const YTRegion &currentRegion();
     static QIcon iconForRegionId(const QString &regionId);
 
 private:
     static YTRegion r(const QString &name, const QString &id);
-    static YTRegion regionById(const QString &id);
+    static const YTRegion &regionById(const QString &id);
     YTRegions();
 
 };
